/*
  ---- Delphes ----
  A Fast Simulator for general purpose LHC detector
  S. Ovyn ~~~~ severine.ovyn@uclouvain.be

  Center for Particle Physics and Phenomenology (CP3)
  Universite Catholique de Louvain (UCL)
  Louvain-la-Neuve, Belgium
*/

/// \file Delphes.cpp
/// \brief executable for the Delphes

#include "TApplication.h"
#include "interface/FrogUtil.h"
#include "interface/SmearUtil.h"
#include <iostream>
using namespace std;

int main(int argc, char *argv[])
{
  int appargc = 2;
  char *appName = "Delphes";
  char *appargv[] = {appName, "-b"};
  TApplication app(appName, &appargc, appargv);
  
  if(argc != 2 && argc != 3) {
    cout << " Usage: " << argv[0] << " input_file [N_events]" << endl;
    cout << " input_file - root file containing the events to display" << endl;
    cout << " detector_card - Datacard containing resolution variables for the detector simulation (optional) "<<endl;
    exit(1);
  }

// 1. ********** initialisation ***********
  //read the input *root file
  string inputfilename(argv[1]);
  if(inputfilename.find(".root") > inputfilename.length() ) {
    cout << "output_file should be a .root file!\n"; 
    exit(1);
  }

  //data card
  string DetDatacard("");
  if(argc==3)  DetDatacard =argv[2];

  //create output log-file name
  string forLog = inputfilename;
  string LogName = forLog.erase(forLog.find(".root"));
  LogName = LogName+"_FROG.log";



  //Smearing information
  RESOLution *DET = new RESOLution();
  DET->ReadDataCard(DetDatacard);
  DET->Logfile(LogName);

 
// 2 ************** FROG display
  FrogDisplay *FROG = new FrogDisplay();
  FROG->BuidEvents(inputfilename,DET->NEvents_Frog);
  FROG->BuildGeom(DetDatacard);

  cout << "** Exiting..." << endl;
  delete FROG;
}
